Package: locdiff
Type: Package
Title: Local Diffusion Exponent
Version: 1.4
Authors@R: c(
    person(given = "Chun-Xiao", family = "Nie", 
           email = "niechunxiao2009@163.com", 
           role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-7790-0803"))
  )
Maintainer: Chun-Xiao Nie <niechunxiao2009@163.com>
Description: The local diffusion exponent for undirected, unweighted networks characterizes the speed of local diffusion from a specified node and depends on the resistance distance.
License: GPL-3
Encoding: UTF-8
Depends: igraph, MASS
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2026-06-20 10:31:45 UTC; niech
Author: Chun-Xiao Nie [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-7790-0803>)
Repository: CRAN
Date/Publication: 2026-06-24 09:50:07 UTC
