% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/renyiindex.R
\name{renyiindex}
\alias{renyiindex}
\title{Compute Rényi's index for a wealth vector}
\usage{
renyiindex(w, alpha)
}
\arguments{
\item{w}{Numeric vector of wealth values (non-negative, at least one positive).}

\item{alpha}{Positive parameter controlling the sensitivity of the index.}
}
\value{
The Rényi index, a number between 0 and 1.
}
\description{
Compute Rényi's index for a wealth vector
}
\examples{
renyiindex(runif(100,0.1,1), 2)
}
\references{
Eliazar, Iddo. "Randomness, evenness, and Rényi’s index." Physica A: Statistical Mechanics and its Applications 390.11 (2011): 1982-1990.
}
